@@ -46,7 +46,7 @@ public:
     Q_PROPERTY(QString icon READ icon CONSTANT)
     Q_PROPERTY(bool hasSubCategories READ hasSubCategories CONSTANT)
     Q_PROPERTY(bool shouldShowTechnical READ shouldShowTechnical CONSTANT)
-    explicit Category(const QSet<QString>& pluginNames, QObject* parent = 0);
+    explicit Category(QSet<QString>  pluginNames, QObject* parent = nullptr);
     ~Category();
 
     QString name() const;
