@@ -31,7 +31,7 @@ class KNSBackendTest : public QObject
 {
     Q_OBJECT
     public:
-        explicit KNSBackendTest(QObject* parent = 0);
+        explicit KNSBackendTest(QObject* parent = nullptr);
 
     private slots:
         void wrongBackend();
