@@ -26,7 +26,7 @@
 #include <ReviewsBackend/AbstractReviewsBackend.h>
 #include <Transaction/Transaction.h>
 #include <MuonBackendsFactory.h>
-#include <MuonMainWindow.h>
+#include <KXmlGuiWindow>
 #include "Transaction/TransactionModel.h"
 #include "Category/CategoryModel.h"
 #include <QDebug>
@@ -49,6 +49,26 @@ ResourcesModel::ResourcesModel(QObject* parent, bool load)
     : QAbstractListModel(parent)
     , m_initializingBackends(0)
     , m_mainwindow(nullptr)
+    , m_roles(QAbstractItemModel::roleNames().unite({
+        { NameRole, "name" },
+        { IconRole, "icon" },
+        { CommentRole, "comment" },
+        { StateRole, "state" },
+        { RatingRole, "rating" },
+        { RatingPointsRole, "ratingPoints" },
+        { SortableRatingRole, "sortableRating" },
+        { ActiveRole, "active" },
+        { InstalledRole, "isInstalled" },
+        { ApplicationRole, "application" },
+        { OriginRole, "origin" },
+        { CanUpgrade, "canUpgrade" },
+        { PackageNameRole, "packageName" },
+        { IsTechnicalRole, "isTechnical" },
+        { CategoryRole, "category" },
+        { SectionRole, "section" },
+        { MimeTypes, "mimetypes" }
+        })
+    )
 {
     init(load);
     connect(this, SIGNAL(allInitialized()), SIGNAL(fetchingChanged()));
@@ -66,12 +86,8 @@ void ResourcesModel::init(bool load)
 }
 
 ResourcesModel::ResourcesModel(const QString& backendName, QObject* parent)
-    : QAbstractListModel(parent)
-    , m_initializingBackends(0)
-    , m_mainwindow(0)
+    : ResourcesModel(parent, false)
 {
-    init(false);
-    Q_ASSERT(!s_self);
     s_self = this;
     registerBackendByName(backendName);
 }
@@ -83,27 +99,7 @@ ResourcesModel::~ResourcesModel()
 
 QHash<int, QByteArray> ResourcesModel::roleNames() const
 {
-    QHash<int, QByteArray> roles = QAbstractItemModel::roleNames();
-    roles[NameRole] = "name";
-    roles[IconRole] = "icon";
-    roles[CommentRole] = "comment";
-    roles[StateRole] = "state";
-    roles[RatingRole] = "rating";
-    roles[RatingPointsRole] = "ratingPoints";
-    roles[SortableRatingRole] = "sortableRating";
-    roles[ActiveRole] = "active";
-    roles[InstalledRole] = "isInstalled";
-    roles[ApplicationRole] = "application";
-    roles[OriginRole] = "origin";
-    roles[CanUpgrade] = "canUpgrade";
-    roles[PackageNameRole] = "packageName";
-    roles[IsTechnicalRole] = "isTechnical";
-    roles[CategoryRole] = "category";
-    roles[SectionRole] = "section";
-    roles[MimeTypes] = "mimetypes";
-    roles.remove(Qt::EditRole);
-    roles.remove(Qt::WhatsThisRole);
-    return roles;
+    return m_roles;
 }
 
 void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
@@ -153,7 +149,7 @@ AbstractResource* ResourcesModel::resourceAt(int row) const
         else
             return it->at(row);
     }
-    return 0;
+    return nullptr;
 }
 
 QModelIndex ResourcesModel::resourceIndex(AbstractResource* res) const
@@ -324,7 +320,7 @@ AbstractResource* ResourcesModel::resourceByPackageName(const QString& name)
             return res;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 int ResourcesModel::updatesCount() const
@@ -392,7 +388,7 @@ void ResourcesModel::registerBackendByName(const QString& name)
     addResourcesBackend(f.backend(name));
 }
 
-void ResourcesModel::integrateMainWindow(MuonMainWindow* w)
+void ResourcesModel::integrateMainWindow(KXmlGuiWindow* w)
 {
     Q_ASSERT(w->thread()==thread());
     m_mainwindow = w;
@@ -428,3 +424,8 @@ QList<QAction*> ResourcesModel::messageActions() const
     Q_ASSERT(!ret.contains(nullptr));
     return ret;
 }
+
+bool ResourcesModel::isBusy() const
+{
+    return TransactionModel::global()->rowCount() > 0;
+}
